@@ -4,7 +4,7 @@
 //! with btui you can create beautiful text user interfaces for the terminal.
 //! To get started add `btui` as a dependency to your project:
 //! ```toml
-//! btui = "0.6.7"
+//! btui = "0.6.8"
 //! ```
 //!
 //! # Examples
@@ -34,6 +34,7 @@ pub use ft::{effects, print};
 #[cfg(test)]
 mod tests {
     use crate::effects::Color::Black;
+    use crate::pbar::*;
     use crate::print::fg;
     use crate::Terminal;
     #[test]
@@ -46,7 +47,26 @@ mod tests {
         match t.println("Hello World!") {
             Ok(_) => (),
             Err(e) => panic!("{}", e),
-
+        }
+    }
+    #[test]
+    fn progressbar() {
+        let t: Terminal = Terminal::default();
+        let mut pbar = ProgressBar::new("test", '-', '#');
+        pbar.set_progress(75.6);
+        match t.println(format!("{}", pbar.render())) {
+            Ok(_) => (),
+            Err(e) => panic!("{}", e),
+        }
+    }
+    #[test]
+    fn extprogressbar() {
+        let t: Terminal = Terminal::default();
+        let mut pbar = ExtProgressBar::new("[=> ]", "test");
+        pbar.set_progress(75.6);
+        match t.println(format!("{}", pbar.render())) {
+            Ok(_) => (),
+            Err(e) => panic!("{}", e),
         }
     }
 }
